pub struct R { /* private fields */ }Expand description
Value read from the register
Implementations
Sourceimpl R
impl R
Sourcepub fn ep_set_int(&self) -> EP_SET_INTR
pub fn ep_set_int(&self) -> EP_SET_INTR
Bits 0:9 - If software writes a one to one of these bits, the corresponding USB interrupt status bit is set. When this register is read, the same value as the USB interrupt status register is returned.
Sourcepub fn frame_set_int(&self) -> FRAME_SET_INTR
pub fn frame_set_int(&self) -> FRAME_SET_INTR
Bit 30 - If software writes a one to one of these bits, the corresponding USB interrupt status bit is set. When this register is read, the same value as the USB interrupt status register is returned.
Sourcepub fn dev_set_int(&self) -> DEV_SET_INTR
pub fn dev_set_int(&self) -> DEV_SET_INTR
Bit 31 - If software writes a one to one of these bits, the corresponding USB interrupt status bit is set. When this register is read, the same value as the USB interrupt status register is returned.